What is Promus? — promus 0.1.0 documentation

# What is Promus?

Promus is a remote manager designed to create and manage git repositories in a remote server without the need of administrator privileges. It was designed with the goal of creating your own private repositories in a server to which you have access and allows you to create connections to remote servers between you and your collaborators via ssh keys.

Promus is your personal butler. You let promus send invitations to your collaborators so that they may access your account via ssh keys and you specify in each of the repositories an access control list (acl) in which you write down the names of the administrators for the repositories (who have more control over the project) and the users.